local sti = require "libs.STI"

function love.load()
	print(sti.version)
	
	i		= 1
	speed	= 256
	
	-- Load multiple maps
	maps = {
		sti.new("assets/maps/map01"),
		sti.new("assets/maps/map02"),
		sti.new("assets/maps/iso"),
		sti.new("assets/maps/stag"),
	}
	
	col = {}
	
	for k=1, #maps do
		local layer = 2
		local sprite = "kim"
		
		if k % 2 == 0 then
			layer = 3
			sprite = "osama"
		end
		
		-- Add a Custom Layer
		maps[k]:addCustomLayer("Sprite Layer", layer)
		
		local spriteLayer = maps[k].layers["Sprite Layer"]
		
		-- Add Custom Data
		spriteLayer.sprite = {
			image = love.graphics.newImage("assets/sprites/"..sprite..".png"),
			x = 495,
			y = 462,
			r = 0,
		}
		
		-- Override Update callback
		function spriteLayer:update(dt)
			if k % 2 == 0 then
				self.sprite.r = self.sprite.r - math.rad(90 * dt)
			else
				self.sprite.r = self.sprite.r + math.rad(90 * dt)
			end
		end
		
		-- Override Draw callback
		function spriteLayer:draw()
			local image = self.sprite.image
			local x = math.floor(self.sprite.x)
			local y = math.floor(self.sprite.y)
			local r = self.sprite.r
			love.graphics.draw(image, x, y, r)
		end
		
		col[k] = maps[k]:getCollisionMap(1)
	end
end

function love.update(dt)
	-- Cap speed
	if speed < 128	then speed = 128 end
	if speed > 512	then speed = 512 end
	
	-- Update sprite's coordinates
	local sprite = maps[i].layers["Sprite Layer"].sprite
	local down = love.keyboard.isDown
	
	if down("w") or down("up")		then sprite.y = sprite.y - speed * dt end
	if down("s") or down("down")	then sprite.y = sprite.y + speed * dt end
	if down("a") or down("left")	then sprite.x = sprite.x - speed * dt end
	if down("d") or down("right")	then sprite.x = sprite.x + speed * dt end
	
	for _, map in pairs(maps) do
		map:update(dt)
	end
end

function love.draw()
	local sprite = maps[i].layers["Sprite Layer"].sprite
	local ww = love.graphics.getWidth()
	local wh = love.graphics.getHeight()
	local tx = math.floor(-sprite.x + ww / 2 - 16)
	local ty = math.floor(-sprite.y + wh / 2 - 16)
	
	-- Draw sprite in centre of screen
	love.graphics.push()
	love.graphics.translate(tx, ty)
	maps[i]:setDrawRange(tx, ty, ww, wh)
	maps[i]:draw()
	--maps[i]:drawCollisionMap(col[i])
	love.graphics.pop()
	
	local dir = "WASD / UDLR to move"
	local spd = "ctrl / alt to speed"
	local tab = "Tab to switch map"
	love.graphics.setColor(255, 0, 0, 255)
	love.graphics.print(dir, 30, 30)
	love.graphics.print(spd, 30, 45)
	love.graphics.print(tab, 30, 60)
	love.graphics.setColor(255, 255, 255, 255)
end

function love.keypressed(key, isrepeat)
	if key == "lctrl"	then speed = speed - 64 end
	if key == "lalt"	then speed = speed + 64 end
	
	if key == "tab" then
		i = i + 1
		if i > #maps then i = 1 end
	end
end

function love.resize(w, h)
	for k=1, #maps do
		maps[k]:resize(w, h)
	end
end
